"""Packs group together related settings and configuration files."""
from .nbclassic import apply_pack as nbclassic  # noqa
from .mariadb import apply_pack as mariadb  # noqa
from .tutorial_server import apply_pack as tutorial_server  # noqa
from .jupyterlab import apply_pack as jupyterlab  # noqa
