"""Core settings processing functionality."""
from .content import apply_core as content  # noqa
from .env import apply_core as env  # noqa
from .scripts import apply_core as scripts  # noqa
from .services import apply_core as services  # noqa
from .web_apps import apply_core as web_apps  # noqa
